pub struct Spin;Expand description
A strategy that rapidly spins while informing the CPU that it should power
down non-essential components via core::hint::spin_loop.
Note that spinning is a ‘dumb’ strategy and most schedulers cannot correctly differentiate it from useful work, thereby misallocating even more CPU time to the spinning process. This is known as priority inversion.
If you see signs that priority inversion is occurring, consider switching to
Yield or, even better, not using a spinlock at all and opting for a proper
scheduler-aware lock. Remember also that different targets, operating systems,
schedulers, and even the same scheduler with different workloads will exhibit
different behaviour. Just because priority inversion isn’t occurring in your
tests does not mean that it will not occur. Use a scheduler-aware lock if at
all possible.